function [b, F, df1, df2, p, R2, pred] = teg_regression(varargin)

% function [b, F, df1, df2, p, R2, pred] = teg_regression(X, y, report)

X = varargin{1};

v = var(X);
if isempty(find(v == 0)),
    X = X - ones(size(X, 1), 1) * mean(X);
end;

y = varargin{2};
y = y - mean(y);
if length(varargin) > 2,
    report = varargin{3};
else
    report = 0;
end;
b = inv(X' * X) * X' * y;
pred = X * b;
df1 = size(X, 2);
MSM = SS(pred, mean(pred)) / df1;
df2 = (size(y, 1) - 1) - df1;
MSE = SS(pred - y, 0) / df2;
F = MSM / MSE;
p = teg_fsig(F, df1, df2);
R2 = var(pred) / var(y);

if report == 1,
    fprintf(['F(' num2str(df1) ', ' num2str(df2) ') = ' num2str(F) ', p = ' num2str(p) ', R2 = ' num2str(R2)]);
    if p < 0.05,
        fprintf(' ***\n');
    else,
        fprintf(' \n');
    end;
end;

function signi = teg_fsig(F, df1, df2)

if isnan(F),
    signi = NaN;
    return;
end;

x = df1 * F / (df1 * F + df2);
a = df1 / 2;
b = df2 / 2;
try,
    signi = 1 - betainc(x, a, b);
catch,
    disp('error in teg_fsig');
    signi = 0.666;
end;
